use std::path::{PathBuf, Path};
use camino::Utf8PathBuf;
use egui::ahash::HashMap;
use serde::{Deserialize, Serialize};


#[derive(Debug, Clone, Serialize, Deserialize)]
pub struct Config {
    steam_library_path: Utf8PathBuf,
    arma: ConfigArma3,
}

#[derive(Debug, Clone, Serialize, Deserialize)]
pub struct ConfigArma3 {
    env: Vec<(String, String)>,
    args: Vec<String>,
}

impl Config {
    pub fn parse(path: &Path) -> anyhow::Result<Self> {
        let s = std::fs::read_to_string(path)?;
        Ok(toml::from_str(&s)?)
    }

    pub fn get_arma_path(&self) -> PathBuf {
        let mut p = self.steam_library_path.clone();
        p.push("steamapps/common/Arma 3/");
        p.into()
    }
    pub fn get_arma_pfx_path(&self) -> PathBuf {
        let mut p = self.steam_library_path.clone();
        p.push("steamapps/compatdata/107410/pfx/drive_c/");
        p.into()
    }
}
