use std::path::Path;
use std::fmt::Write;
use serde::{Deserialize, Serialize};


#[derive(Debug, Clone, Serialize, Deserialize, Default)]
#[serde(rename = "addons-presets")]
pub struct MPInt {
    #[serde(rename = "last-update")]
    pub last_update: MPIntLastUpdate,
    #[serde(rename = "published-ids")]
    pub published_ids: MPIntPublishedModIds,
    #[serde(rename = "dlcs-appids")]
    pub dlcs_appids: MPIntDlcsAppIds,
} 

#[derive(Debug, Clone, Serialize, Deserialize, Default)]
pub struct MPIntLastUpdate {
    // rfc3339
    #[serde(rename = "$value")]
    pub value: chrono::DateTime<chrono::Local>, 
}

#[derive(Debug, Clone, Serialize, Deserialize, Default)]
pub struct MPIntPublishedModIds {
    #[serde(rename = "$value")]
    pub value: Vec<MPIntModId>, 
}

#[derive(Debug, Clone, Serialize, Deserialize, Default)]
pub struct MPIntModId {
    #[serde(rename = "$value")]
    pub value: String,
}
#[derive(Debug, Clone, Serialize, Deserialize, Default)]
pub struct MPIntDlcsAppIds;

#[derive(Debug, Clone, Copy, PartialEq, Eq, PartialOrd, Ord)]
pub enum MPIntModIdType {
    Steam,
    Local,
}

impl MPInt {
    pub fn parse(path: &Path) -> anyhow::Result<Self> {
        let s = std::fs::read_to_string(path)?;
        Ok(quick_xml::de::from_str(&s)?)
    }
    pub fn write(&self, path: &Path) -> anyhow::Result<()> {
        let mut indent_idx = 0;
        let mut buf = String::new();
        let f = &mut buf;

        writeln!(f, "<?xml version=\"1.0\" encoding=\"utf-8\"?>")?;
        writeln!(f, "<addons-presets>")?;
        writeln!(f, "  <last-update>{}</last-update>", self.last_update.value.to_rfc3339())?;
        writeln!(f, "  <published-ids>")?;
        for id in &self.published_ids.value { 
            writeln!(f, "   <id>{}</id>", id.value)?;
        }
    //<id>steam:463939057</id>
    // <id>local:Z:\HOME\MCORANGE\.LOCAL\SHARE\STEAM\STEAMAPPS\WORKSHOP\CONTENT\107410\2466229756\</id>
        writeln!(f, "  </published-ids>")?;
        writeln!(f, "  <dlcs-appids />")?;
        writeln!(f, "</addons-presets>")?;

        std::fs::write(path, buf)?;
        Ok(())
    }
}

